SystemOrganization addCategory: #'OpenCourses-Tests'!
SystemOrganization addCategory: #OpenCourses!

TestCase subclass: #UserManagerTest
	instanceVariableNames: 'emptyUserManager nonEmptyUserManager'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses-Tests'!

!UserManagerTest methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:33'!
setUp
	emptyUserManager := UserManager new.
	nonEmptyUserManager := UserManager new.
	nonEmptyUserManager registerNewUser: 'john' password: '123admin' email: 'johnadmin@me.com'.! !

!UserManagerTest methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:57'!
testLogin
	| loggedUser |
	self
		should: [nonEmptyUserManager login: 'emailDoesntExist' password: '123admin']
		raise: Error.
	self
		should: [nonEmptyUserManager login: 'johnadmin@me.com' password: 'wrongPassword']
		raise: Error.
	loggedUser := User new email: 'johnadmin@me.com'.
	self
		should: [nonEmptyUserManager login: 'johnadmin@me.com' password: '123admin'.
			Session user = loggedUser]! !

!UserManagerTest methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:34'!
testRegisterNewUser
	| createdUser |
	createdUser := User new name: 'john';
				 password: '123admin';
				 email: 'johnadmin@me.com'.
	self
		shouldnt: [emptyUserManager hasUser: createdUser].
	emptyUserManager
		registerNewUser: 'john'
		password: '123admin'
		email: 'johnadmin@me.com'.
	self
		assert: (emptyUserManager hasUser: createdUser)! !

!UserManagerTest methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:35'!
testTryToRegisterAnAlreadyRegisteredUser
	self
		should: [nonEmptyUserManager
				registerNewUser: 'jon'
				password: '123admin321'
				email: 'johnadmin@me.com']
		raise: Error! !

TestCase subclass: #UserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses-Tests'!

Object subclass: #DidacticMaterial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

Object subclass: #MaterialManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

Object subclass: #Session
	instanceVariableNames: ''
	classVariableNames: 'CurrentUser'
	poolDictionaries: ''
	category: 'OpenCourses'!

!Session class methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:58'!
user
	^CurrentUser! !

!Session class methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:58'!
user: aUser
	CurrentUser := aUser! !

Object subclass: #User
	instanceVariableNames: 'name password email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!User methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 17:15'!
= aUser 
	^ self email = aUser email! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
email
	"Answer the value of email"

	^ email! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
email: anObject
	"Set the value of email"

	email := anObject! !

!User methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 17:33'!
hash
	^ email hash! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:34'!
name
	"Answer the value of name"
	^ name! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:31'!
name: anObject
	"Set the value of name"

	name := anObject! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
password
	"Answer the value of password"

	^ password! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
password: anObject
	"Set the value of password"

	password := anObject! !

Object subclass: #UserManager
	instanceVariableNames: 'userList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!UserManager methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 17:08'!
hasUser: aUser 
	^ userList includes: aUser! !

!UserManager methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 17:26'!
initialize
	super initialize.
	userList := Set new! !

!UserManager methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 18:59'!
login: email password: password 
	| user registeredUser |
	user := User new email: email;
				 password: password.
	registeredUser := userList
				like: user
				ifAbsent: [Error signal: 'User/Password incorrect!!'].
	user password = registeredUser password
		ifTrue: [Session user: registeredUser]
		ifFalse: [Error signal: 'User/Password incorrect!!']! !

!UserManager methodsFor: 'as yet unclassified' stamp: 'cmb 5/10/2013 17:56'!
registerNewUser: name password: password email: email 
	| newUser |
	newUser := User new name: name;
				 password: password;
				 email: email.
	(userList includes: newUser)
		ifFalse: [userList add: newUser]
		ifTrue: [Error signal: 'Duplicated user']! !

!UserManager methodsFor: 'accessing' stamp: 'cmb 5/10/2013 17:28'!
userList
	"Answer the value of userList"

	^ userList! !

!UserManager methodsFor: 'accessing' stamp: 'cmb 5/10/2013 17:28'!
userList: anObject
	"Set the value of userList"

	userList := anObject! !
